]> git.mxchange.org Git - core.git/blobdiff - index.php
Continued:
[core.git] / index.php
index 0a3ef741158afd0be661a3d36b0c1b63d8e4c89b..9f6a0e17e4db4680a6a36ff8ef325c20a1755962 100644 (file)
--- a/index.php
+++ b/index.php
@@ -1,4 +1,12 @@
 <?php
+// Own namespace (watch out: core)
+namespace CoreFramework\EntryPoint;
+
+// Import framework stuff
+use CoreFramework\Configuration\FrameworkConfiguration;
+use CoreFramework\Helper\Application\ApplicationHelper;
+use CoreFramework\Loader\ClassLoader;
+
 /**
  * The main class with the entry point to the whole application. This class
  * "emulates" Java's entry point call. Additionally it covers local
@@ -117,7 +125,7 @@ final class ApplicationEntryPoint {
                        $applicationInstance = NULL;
 
                        // Is the class there?
-                       if (class_exists('ApplicationHelper')) {
+                       if (class_exists('CoreFramework\Helper\Application\ApplicationHelper')) {
                                // Get application instance
                                $applicationInstance = ApplicationHelper::getSelfInstance();
 
@@ -183,24 +191,32 @@ final class ApplicationEntryPoint {
        }
 
        /**
* The application's main entry point. This class isolates some local
         * variables which shall not become visible to outside because of security
-        * concerns. We are doing this here to "emulate" the well-known entry
-        * point in Java.
+        * concerns. This is done here to "emulate" the well-known entry point in
+        * Java.
         *
         * @return      void
         */
        public static final function main () {
// Load config file
                require(self::detectCorePath() . '/inc/config.php');
 
+               // Get a new configuration instance
+               $cfg = FrameworkConfiguration::getSelfInstance();
+
+               // Load bootstrap class
+               require($cfg->getConfigEntry('base_path') . 'inc/bootstrap/class_BootstrapFramework.php');
+
+               // ----- Below is deprecated -----
+
                // Load all include files
                require($cfg->getConfigEntry('base_path') . 'inc/includes.php');
 
                // Include the application selector
                require($cfg->getConfigEntry('base_path') . 'inc/selector.php');
-       } // END - main()
-} // END - class
+       }
+}
 
 // Developer mode active? Comment out if no dev!
 define('DEVELOPER', TRUE);
@@ -210,8 +226,5 @@ define('DEVELOPER', TRUE);
 
 //xdebug_start_trace();
 
-// Do not remove the following line:
+// Call above main() method
 ApplicationEntryPoint::main();
-
-// [EOF]
-?>
@@ -183,24 +191,32 @@ final class ApplicationEntryPoint {
 
        /**
-        * The application's main entry point. This class isolates some local
+        * The framework's main entry point. This class isolates some local
         * variables which shall not become visible to outside because of security
@@ -183,24 +191,32 @@ final class ApplicationEntryPoint {
         */
        public static final function main () {
-               // Load config file
+               // Load config file, this provides $cfg
                require(self::detectCorePath() . '/inc/config.php');
 